# Changelog

## [V0.1.2a1](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.2a1) (2024-09-02)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.1a7...V0.1.2a1)

## [V0.1.1a7](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.1a7) (2024-06-02)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.1a6...V0.1.1a7)

**Fixed bugs:**

- Use generic tempdir path for broad support [\#68](https://github.com/OpenVoiceOS/ovos-backend-client/issues/68)
- fix: allow cross-platform tempdir usage [\#69](https://github.com/OpenVoiceOS/ovos-backend-client/pull/69) ([mikejgray](https://github.com/mikejgray))

## [V0.1.1a6](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.1a6) (2024-04-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.1a5...V0.1.1a6)

**Fixed bugs:**

- improve geolocation [\#67](https://github.com/OpenVoiceOS/ovos-backend-client/pull/67) ([JarbasAl](https://github.com/JarbasAl))

## [V0.1.1a5](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.1a5) (2024-02-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.1a4...V0.1.1a5)

**Implemented enhancements:**

- feat/refresh\_oauth\_token [\#65](https://github.com/OpenVoiceOS/ovos-backend-client/pull/65) ([JarbasAl](https://github.com/JarbasAl))

**Fixed bugs:**

- OAuthApplicationDatabase update\_application infinite recursion [\#60](https://github.com/OpenVoiceOS/ovos-backend-client/issues/60)

## [V0.1.1a4](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.1a4) (2024-01-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.1a3...V0.1.1a4)

**Fixed bugs:**

- Database: Fix update\_application\(\) method [\#62](https://github.com/OpenVoiceOS/ovos-backend-client/pull/62) ([forslund](https://github.com/forslund))

## [V0.1.1a3](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.1a3) (2024-01-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.1a2...V0.1.1a3)

**Fixed bugs:**

- Fix path errors in Database init [\#58](https://github.com/OpenVoiceOS/ovos-backend-client/pull/58) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.1.1a2](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.1a2) (2023-12-30)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.1a1...V0.1.1a2)

**Fixed bugs:**

- Fix location config reference [\#57](https://github.com/OpenVoiceOS/ovos-backend-client/pull/57) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.1.1a1](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.1a1) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0...V0.1.1a1)

**Merged pull requests:**

- packaging/update\_imports [\#56](https://github.com/OpenVoiceOS/ovos-backend-client/pull/56) ([JarbasAl](https://github.com/JarbasAl))

## [V0.1.0](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a14...V0.1.0)

## [V0.1.0a14](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a14) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a13...V0.1.0a14)

**Merged pull requests:**

- bump utils [\#54](https://github.com/OpenVoiceOS/ovos-backend-client/pull/54) ([JarbasAl](https://github.com/JarbasAl))

## [V0.1.0a13](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a13) (2023-10-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a12...V0.1.0a13)

**Fixed bugs:**

- Update WW upload [\#52](https://github.com/OpenVoiceOS/ovos-backend-client/pull/52) ([NeonDaniel](https://github.com/NeonDaniel))

**Closed issues:**

- Unable to upload wake word. [\#47](https://github.com/OpenVoiceOS/ovos-backend-client/issues/47)

## [V0.1.0a12](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a12) (2023-09-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a11...V0.1.0a12)

**Fixed bugs:**

- PM init configured backend api [\#51](https://github.com/OpenVoiceOS/ovos-backend-client/pull/51) ([emphasize](https://github.com/emphasize))

## [V0.1.0a11](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a11) (2023-09-19)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a10...V0.1.0a11)

**Fixed bugs:**

- fix remote download loop [\#50](https://github.com/OpenVoiceOS/ovos-backend-client/pull/50) ([emphasize](https://github.com/emphasize))

## [V0.1.0a10](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a10) (2023-09-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a9...V0.1.0a10)

**Fixed bugs:**

- fix dataset upload [\#48](https://github.com/OpenVoiceOS/ovos-backend-client/pull/48) ([JarbasAl](https://github.com/JarbasAl))

## [V0.1.0a9](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a9) (2023-09-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a8...V0.1.0a9)

**Fixed bugs:**

- fix DeviceIdentity attribute access [\#49](https://github.com/OpenVoiceOS/ovos-backend-client/pull/49) ([emphasize](https://github.com/emphasize))

## [V0.1.0a8](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a8) (2023-08-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a7...V0.1.0a8)

## [V0.1.0a7](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a7) (2023-08-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a6...V0.1.0a7)

**Fixed bugs:**

- fix stt/ww dataset endpoints mixup [\#46](https://github.com/OpenVoiceOS/ovos-backend-client/pull/46) ([JarbasAl](https://github.com/JarbasAl))

## [V0.1.0a6](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a6) (2023-06-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a5...V0.1.0a6)

**Merged pull requests:**

- Import more xdg functions from ovos\_config rather than ovos\_utils [\#44](https://github.com/OpenVoiceOS/ovos-backend-client/pull/44) ([PureTryOut](https://github.com/PureTryOut))

## [V0.1.0a5](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a5) (2023-06-21)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a4...V0.1.0a5)

**Merged pull requests:**

- Import xdg functions from ovos\_config rather than ovos\_utils [\#43](https://github.com/OpenVoiceOS/ovos-backend-client/pull/43) ([PureTryOut](https://github.com/PureTryOut))

## [V0.1.0a4](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a4) (2023-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a3...V0.1.0a4)

**Implemented enhancements:**

- feat/admin\_update\_backend\_config [\#42](https://github.com/OpenVoiceOS/ovos-backend-client/pull/42) ([JarbasAl](https://github.com/JarbasAl))

## [V0.1.0a3](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a3) (2023-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a2...V0.1.0a3)

**Fixed bugs:**

- hotfix/rebase mess up in \#30 [\#41](https://github.com/OpenVoiceOS/ovos-backend-client/pull/41) ([JarbasAl](https://github.com/JarbasAl))

## [V0.1.0a2](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a2) (2023-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a9...V0.1.0a2)

**Implemented enhancements:**

- feat/DatabaseApi [\#30](https://github.com/OpenVoiceOS/ovos-backend-client/pull/30) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a9](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a9) (2023-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a8...V0.0.7a9)

**Breaking changes:**

- deprecate dead backends [\#39](https://github.com/OpenVoiceOS/ovos-backend-client/pull/39) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a8](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a8) (2023-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a7...V0.0.7a8)

**Merged pull requests:**

- Updated dependencies and automation [\#34](https://github.com/OpenVoiceOS/ovos-backend-client/pull/34) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.7a7](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a7) (2023-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a6...V0.0.7a7)

**Implemented enhancements:**

- add cache + fix geolocation [\#40](https://github.com/OpenVoiceOS/ovos-backend-client/pull/40) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a6](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a6) (2023-05-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a5...V0.0.7a6)

**Merged pull requests:**

- add package data [\#38](https://github.com/OpenVoiceOS/ovos-backend-client/pull/38) ([emphasize](https://github.com/emphasize))

## [V0.0.7a5](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a5) (2023-04-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a4...V0.0.7a5)

**Fixed bugs:**

- Personal-backend: Workaround deadlock [\#37](https://github.com/OpenVoiceOS/ovos-backend-client/pull/37) ([forslund](https://github.com/forslund))

**Closed issues:**

- Double acquire of combo-lock [\#36](https://github.com/OpenVoiceOS/ovos-backend-client/issues/36)

## [V0.0.7a4](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a4) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a3...V0.0.7a4)

**Implemented enhancements:**

- fix offline geolocate [\#33](https://github.com/OpenVoiceOS/ovos-backend-client/pull/33) ([emphasize](https://github.com/emphasize))

**Closed issues:**

- 'what is the weather in baltimore' returns an error \#30 [\#31](https://github.com/OpenVoiceOS/ovos-backend-client/issues/31)

## [V0.0.7a3](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a3) (2023-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a2...V0.0.7a3)

**Merged pull requests:**

- fix AudioFile offline import [\#35](https://github.com/OpenVoiceOS/ovos-backend-client/pull/35) ([emphasize](https://github.com/emphasize))

## [V0.0.7a2](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a2) (2023-02-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a1...V0.0.7a2)

**Fixed bugs:**

- fix/pairing\_checks\_for\_offline [\#29](https://github.com/OpenVoiceOS/ovos-backend-client/pull/29) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a1](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a1) (2023-02-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6...V0.0.7a1)

**Implemented enhancements:**

- Add reverse geo api [\#27](https://github.com/OpenVoiceOS/ovos-backend-client/pull/27) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6) (2023-02-01)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a12...V0.0.6)

## [V0.0.6a12](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a12) (2023-02-01)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a11...V0.0.6a12)

**Merged pull requests:**

- Update offline backend to only load remote config instead of all config [\#26](https://github.com/OpenVoiceOS/ovos-backend-client/pull/26) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.6a11](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a11) (2023-01-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a10...V0.0.6a11)

**Merged pull requests:**

- add shell\_integration key for oauth db [\#25](https://github.com/OpenVoiceOS/ovos-backend-client/pull/25) ([AIIX](https://github.com/AIIX))

## [V0.0.6a10](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a10) (2022-12-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a9...V0.0.6a10)

**Implemented enhancements:**

- port shared oauth db utils [\#24](https://github.com/OpenVoiceOS/ovos-backend-client/pull/24) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a9](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a9) (2022-10-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a8...V0.0.6a9)

**Fixed bugs:**

- fix/settings\_upload [\#23](https://github.com/OpenVoiceOS/ovos-backend-client/pull/23) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a8](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a8) (2022-10-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a7...V0.0.6a8)

**Merged pull requests:**

- deprecate/mk1\_hardcoded\_pairing\_flow [\#21](https://github.com/OpenVoiceOS/ovos-backend-client/pull/21) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a7](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a7) (2022-10-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a6...V0.0.6a7)

**Fixed bugs:**

- fix/pairing\_retry [\#22](https://github.com/OpenVoiceOS/ovos-backend-client/pull/22) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a6](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a6) (2022-10-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a5...V0.0.6a6)

**Implemented enhancements:**

- pairing\_logs [\#20](https://github.com/OpenVoiceOS/ovos-backend-client/pull/20) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a5](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a5) (2022-10-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a4...V0.0.6a5)

**Fixed bugs:**

- fix/remote\_config [\#19](https://github.com/OpenVoiceOS/ovos-backend-client/pull/19) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a4](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a4) (2022-10-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a3...V0.0.6a4)

**Fixed bugs:**

- Fix typo in OfflineBackend [\#18](https://github.com/OpenVoiceOS/ovos-backend-client/pull/18) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.6a3](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a3) (2022-10-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a2...V0.0.6a3)

**Implemented enhancements:**

- feat/ovos\_backend [\#17](https://github.com/OpenVoiceOS/ovos-backend-client/pull/17) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a2](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a2) (2022-10-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6a1...V0.0.6a2)

**Fixed bugs:**

- fix/pairing\_code\_callback [\#16](https://github.com/OpenVoiceOS/ovos-backend-client/pull/16) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a1](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.6a1) (2022-10-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.5...V0.0.6a1)

**Fixed bugs:**

- fix/ensure\_valid\_urls [\#15](https://github.com/OpenVoiceOS/ovos-backend-client/pull/15) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.5](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.5) (2022-10-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.5a5...V0.0.5)

## [V0.0.5a5](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.5a5) (2022-10-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.5a4...V0.0.5a5)

**Implemented enhancements:**

- make offline DeviceApi slightly more useful [\#14](https://github.com/OpenVoiceOS/ovos-backend-client/pull/14) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.5a4](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.5a4) (2022-10-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.5a3...V0.0.5a4)

**Fixed bugs:**

- fix/pairing\_check [\#13](https://github.com/OpenVoiceOS/ovos-backend-client/pull/13) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.5a3](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.5a3) (2022-10-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.5a2...V0.0.5a3)

## [V0.0.5a2](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.5a2) (2022-10-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.4a4...V0.0.5a2)

**Implemented enhancements:**

- Feat/multiple backends + rename [\#10](https://github.com/OpenVoiceOS/ovos-backend-client/pull/10) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.4a4](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.4a4) (2022-09-30)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.4a3...V0.0.4a4)

**Implemented enhancements:**

- add backend\_type info to mycroft.conf [\#9](https://github.com/OpenVoiceOS/ovos-backend-client/pull/9) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.4a3](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.4a3) (2022-09-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.4a2...V0.0.4a3)

## [V0.0.4a2](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.4a2) (2022-09-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.4a1...V0.0.4a2)

**Implemented enhancements:**

- feat/remote\_config [\#8](https://github.com/OpenVoiceOS/ovos-backend-client/pull/8) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.4a1](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.4a1) (2022-09-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.3...V0.0.4a1)

## [V0.0.3](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.3) (2022-09-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.1...V0.0.3)

## [V0.0.1](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.1) (2022-09-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.1a4...V0.0.1)

## [V0.0.1a4](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.1a4) (2022-09-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/0.0.2...V0.0.1a4)

**Implemented enhancements:**

- feat/automations [\#7](https://github.com/OpenVoiceOS/ovos-backend-client/pull/7) ([JarbasAl](https://github.com/JarbasAl))
- Feat/pairing manager [\#6](https://github.com/OpenVoiceOS/ovos-backend-client/pull/6) ([JarbasAl](https://github.com/JarbasAl))
- feat/pairing\_manager [\#5](https://github.com/OpenVoiceOS/ovos-backend-client/pull/5) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.2](https://github.com/OpenVoiceOS/ovos-backend-client/tree/0.0.2) (2022-09-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/a4dbde9e07343bbff10ce7072e89d0e56c36ce78...0.0.2)

**Implemented enhancements:**

- feat/precise\_upload\_v2 [\#4](https://github.com/OpenVoiceOS/ovos-backend-client/pull/4) ([JarbasAl](https://github.com/JarbasAl))
- missing wolfram/owm endpoints [\#3](https://github.com/OpenVoiceOS/ovos-backend-client/pull/3) ([JarbasAl](https://github.com/JarbasAl))
- feat/admin\_api [\#2](https://github.com/OpenVoiceOS/ovos-backend-client/pull/2) ([JarbasAl](https://github.com/JarbasAl))
- Feat/set identity path [\#1](https://github.com/OpenVoiceOS/ovos-backend-client/pull/1) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
